from rest_framework import serializers

from discussion.models import Topic
from discussion.serializers import TopicSerializer

from .models import Activity, Answer
from courses.models import Class

from courses_learning_objects.serializers import LearningObjectSerializer as ActivitySerializer, LearningObjectImageSerializer as ActivityImageSerializer


class AnswerSerializer(serializers.ModelSerializer):
    correct = serializers.ReadOnlyField(source='is_correct')
    given = serializers.JSONField()
    topic = serializers.SerializerMethodField()

    class Meta:
        model = Answer
        allow_add_remove = True
        fields = ('id', 'activity', 'correct', 'timestamp', 'given', 'topic')

    def get_topic(self, obj):
        try:
            topic = Topic.objects.prefetch_related('comments', 'comments__comment_replies').get(id=obj.given.get('topic', None))
        except (Topic.DoesNotExist, AttributeError) as e:
            print(e)
            return

        return TopicSerializer(instance=topic, **{'context': self.context}).data

class AnswerActivitySerializer(serializers.ModelSerializer):
    topic = serializers.SerializerMethodField()
    name = serializers.SerializerMethodField()

    class Meta:
        model = Answer
        fields = ('id', 'timestamp', 'topic', 'name')

    def get_topic(self, obj):
        try:
            topic = Topic.objects.prefetch_related('comments', 'comments__comment_replies').get(id=obj.given.get('topic', None))
        except (Topic.DoesNotExist, AttributeError) as e:
            print(e)
            return

        return TopicSerializer(instance=topic, **{'context': self.context}).data
    
    def get_name(self, obj):
        class_activity = Class.objects.filter(course__id=obj.activity.unit.lesson.course.id, students=obj.user)
        
        class_name = []
        for c in class_activity:
            class_name.append(c.name)
        
        return ", ".join(class_name)