(function (angular) {
    'use strict';

    var app = angular.module('courseMaterial.controllers', ['ngCookies']);

    app.controller('CourseMaterialEditorCtrl', ['$scope', '$window', '$sce', 'CourseMaterial','CourseMaterialFile', 'SetLanguage', 'UserLocalStorage',
        function ($scope, $window, $sce, CourseMaterial, CourseMaterialFile, SetLanguage, UserLocalStorage) {
            $scope.courseId = $window.course_id;
            $scope.check_editing = null;
            $scope.file_name = '';
            $scope.files_course = [];

            $scope.editingCourseLanguage = UserLocalStorage.get('editingMaterialLanguage') || UserLocalStorage.get('currentLanguage');
            
            $scope.setLanguage = function(language) {
                UserLocalStorage.set('editingMaterialLanguage', language);
                SetLanguage(language).then(function() {
                    $window.location.reload();
                });
            };

            // Set buttons for the tinyMCE editor
            $scope.tinymceOptions = {
              toolbar: 'bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | quicklink link fullscreen | removeformat'
            };

            $scope.course_materials = CourseMaterial.query({course__id: $scope.courseId}, function (course_materials){
                if(course_materials.length === 1) {
                    $scope.course_material = course_materials[0];
                }
                angular.forEach($scope.course_material.files, function(file, index){
                    if ($scope.editingCourseLanguage === 'pt-br') {
                        if (file.file_pt_br !== null){
                            $scope.files_course.push(file)
                        }
                    }
                    if ($scope.editingCourseLanguage === 'en') {
                        if (file.file_en !== null){
                            $scope.files_course.push(file)
                        }
                    }
                    if ($scope.editingCourseLanguage === 'es') {
                        if (file.file_es !== null){
                            $scope.files_course.push(file)
                        }
                    }
                });
            });

            $scope.save_course_material = function(){
                $scope.course_material.$update({course: $scope.courseId}, function(){
                    // $scope.alert.success('Alterações salvas com sucesso!');
                    $scope.editando = false;
                    $window.location.reload();
                });
            };

            $scope.delete_file = function(file_obj){
                if (confirm('Tem certeza que dejeja apagar este arquivo?')){
                    CourseMaterialFile.delete({id: file_obj.id}, function(){
                        angular.forEach($scope.files_course, function(file, index){
                            if (file.id == file_obj.id){
                                $scope.files_course.splice(index, 1);
                            }
                        });
                    });
                }
            };

            $scope.edit_file = function(file){
               $scope.check_editing = file.id;
               $scope.file_name = file.title;
            };

            $scope.edit_cancel = function(){
                $scope.check_editing = null;
             };

            $scope.save_edit = function(file, new_name){
                var new_name = angular.element('#id_name').val();
                $scope.check_editing = null;

                CourseMaterialFile.update({id: file.id, title:new_name}, function(){
                    angular.forEach($scope.files_course, function(file_obj, index){
                        if (file_obj.id == file.id){
                            file.title=new_name;
                        }
                    });
                });
            };

            $scope.get_as_safe_html = function(html_content) {
                return $sce.trustAsHtml(html_content);
            };
    }]);

    app.controller('CourseMaterialCtrl', ['$scope', '$window', '$location', '$sce', 'CourseMaterial','CourseMaterialFile', 'SetLanguage', 'UserLocalStorage',
        function ($scope, $window, $location, $sce, CourseMaterial, CourseMaterialFile, SetLanguage, UserLocalStorage) {

        $scope.courseSlug = $location.absUrl().split('/');
        $scope.editingCourseLanguage = UserLocalStorage.get('currentLanguage');
        $scope.files_course = [];
        
        $scope.course_materials = CourseMaterial.query({course__slug: $scope.courseSlug[$scope.courseSlug.length - 3]}, function (course_materials){
            if(course_materials.length === 1) {
                $scope.course_material = course_materials[0];
            }

            angular.forEach($scope.course_material.files, function(file, index){
                if ($scope.editingCourseLanguage === 'pt_br') {
                    if (file.file_pt_br !== null){
                        $scope.files_course.push(file)
                    }
                }
                if ($scope.editingCourseLanguage === 'en') {
                    if (file.file_en !== null){
                        $scope.files_course.push(file)
                    }
                }
                if ($scope.editingCourseLanguage === 'es') {
                    if (file.file_es !== null){
                        $scope.files_course.push(file)
                    }
                }
            });
        });
    }]);
})(angular);
