(function(angular){
    'use strict';
    var app = angular.module('profile.controllers', ['ngSanitize']);

    app.controller('UserProfileController', [
        '$scope',
        '$location',
        'UserProfile',
        'CurrentUser',
        'UserAccess',
        function ($scope, $location, TimtecUser, CurrentUser, UserAccess) {
            $scope.language_options = [
                {id:'', name:''},
                {id:'pt-br', name:'PT-BR'},
                {id:'en', name:'EN'},
                {id:'es', name:'ES'}
            ];
            // Log this access
            (new UserAccess({ area: 'profile-page' })).$save();

            $scope.current_user = CurrentUser;

            // remove the last slash
            var abs_url = $location.absUrl();
            if (abs_url.slice(-1) === '/') {
                abs_url = abs_url.slice(0, -1);
            }

            var username = abs_url.split('/').pop();
            $location.absUrl().split('/').indexOf("profile")
            if (username === 'profile' || username === 'edit') {
                // Current user profile
                username = CurrentUser.username;
            }

            TimtecUser.get({id: CurrentUser.id}, function(user_profile) {
                user_profile.is_current_user = (user_profile.id === parseInt(CurrentUser.id, 10));
                $scope.user_profile = user_profile;

                // Try to find at least one valid certificate
                $scope.valid_certificates = false;
                for (var i = 0; i < user_profile.certificates.length; i++) {
                    if(user_profile.certificates[i].approved === true){
                        $scope.valid_certificates = true;
                        break;
                    }
                }
            }, function(error) {
                $scope.user_profile = null;
            });
        }
    ]);

    app.directive("file", function () {
      return {
        require: "ngModel",
        restrict: "A",
        link: function ($scope, el, attrs, ngModel) {
          el.bind("change", function (event) {
            const imgtag = document.getElementById("profile-avatar");
            const img = document.createElement("img");
            const selectedFile = event.target.files[0];
            const reader = new FileReader();
            reader.onload = function(event) {
                img.src = event.target.result;
                const canvas = document.createElement("canvas");
                let ctx = canvas.getContext("2d");

                img.onload = () => {
                    ctx.drawImage(img, 0, 0);
                    const MAX_WIDTH = 400;
                    const MAX_HEIGHT = 300;
                    let width = img.width;
                    let height = img.height;

                    if (width > height) {
                        if (width > MAX_WIDTH) {
                            height *= MAX_WIDTH / width;
                            width = MAX_WIDTH;
                        }
                    } else {
                        if (height > MAX_HEIGHT) {
                            width *= MAX_HEIGHT / height;
                            height = MAX_HEIGHT;
                        }
                    }
                    canvas.width = width;
                    canvas.height = height;
                    ctx = canvas.getContext("2d");
                    ctx.drawImage(img, 0, 0, width, height);

                    const dataurl = canvas.toDataURL("image/png");
                    imgtag.style.backgroundImage = `url(${dataurl})`;
                }
            };
            reader.readAsDataURL(selectedFile);
            ngModel.$setViewValue(selectedFile);
            $scope.$apply();
          });
        },
      };
    });
})(window.angular);
