(function() {
    'use strict';

    angular
        .module('cityParticipationReportList')
        .component('cityParticipationReportList', {
            templateUrl: '/city-participation-report-list.template.html',
            controller: CityParticipationReportListCtrl,
            bindings: {
                date: '<',
                roles: '<',
                cities: '<'
            },
        });

    CityParticipationReportListCtrl.$inject = ['$scope', 'NteParticipationReport'];

    function CityParticipationReportListCtrl ($scope, NteParticipationReport) {

        var ctrl = this;

        ctrl.cities = [];
        ctrl.fetchNtes = throttleDebounce.debounce(1000, fetchNtes);
        ctrl.filterNtes = filterNtes;
        ctrl.filteredNtes = [];
        ctrl.minimized = false;
        ctrl.ntes = [];
        ctrl.openned = 0;
        ctrl.role = '';
        ctrl.search = '';
        ctrl.toggleDetails = toggleDetails;

        ctrl.$onChanges = function() {
            fetchNtes();
        };

        function fetchNtes() {
            var params = { date: ctrl.date };
            ctrl.openned = 0;

            if (ctrl.role) {
                params['role'] = ctrl.role;
            }

            if (ctrl.city && ctrl.ntes) {
                for (var i = 0; i < ctrl.ntes.length; i++) {
                    let nte = ctrl.ntes[i];
                    if (nte.municipios.includes(ctrl.city)) {
                        ctrl.openned = nte.id;
                    }
                }
            } 

            NteParticipationReport.query(params, (data) => {
                ctrl.ntes = data;
                filterNtes();
            });
        }

        function filterNtes() {
            if (ctrl.city) {
                ctrl.filteredNtes = ctrl.ntes.filter(nte => {
                    return nte.municipios.includes(ctrl.city);
                });
            } else {
                ctrl.filteredNtes = ctrl.ntes;
            }
        }

        function toggleDetails() {
            ctrl.minimized = !ctrl.minimized;
        }
    }
})();
