(function() {
    'use strict';
    angular.
        module('userReportList').
        component('userReportList', {
            templateUrl: '/user-report-list.template.html',
            controller: UserReportListCtrl,
            bindings: {
                group: '<',
            },
        });

    UserReportListCtrl.$inject = ['$scope', 'CurrentUser', 'UserReports'];

    function UserReportListCtrl ($scope, CurrentUser, UserReports) {

        var ctrl = this;

        ctrl.keyword = '';
        ctrl.filteredUsers = [];
        ctrl.page = 1;
        ctrl.paginatedUsers = [];
        ctrl.users = [];

        ctrl.old = {};

        ctrl.$onInit = function() {
            fetchUserReportPage(1);
        };

        ctrl.$doCheck = function() {
            if (ctrl.users !== ctrl.old.users || ctrl.keyword !== ctrl.old.keyword) {
                filterUsers();
                paginateUsers();
            } else if (ctrl.page !== ctrl.old.page) {
                paginateUsers();
            }
            ctrl.old.keyword = ctrl.keyword;
            ctrl.old.page = ctrl.page;
            ctrl.old.users = ctrl.users;
        };

        function fetchUserReportPage(page) {
            UserReports.get({ group: ctrl.group.id, page }, (data) => {
                const usersList = ctrl.users.slice();
                usersList.splice((page - 1) * 50, 0, ...data.results);
                ctrl.users = usersList;
                if (page === 1) {
                    const totalPages = Math.ceil(data.count / 50);
                    for (let extraPage = 2; extraPage <= totalPages; extraPage++) {
                        fetchUserReportPage(extraPage);
                    }
                }
            });
        }

        function filterUsers() {
            const keyword = ctrl.keyword.toLowerCase();
            if (keyword && keyword.length >= 3) {
                ctrl.page = 1;
                ctrl.filteredUsers = ctrl.users.filter(user => {
                    if (!user) return false;
                    return user.name.toLowerCase().includes(keyword)
                        || user.email.toLowerCase().includes(keyword)
                        || user.username.includes(keyword);
                });
            } else {
                ctrl.page = 1;
                ctrl.filteredUsers = ctrl.users;
            }
        }

        function paginateUsers() {
            ctrl.paginatedUsers = ctrl.filteredUsers.slice((ctrl.page - 1) * 100, (ctrl.page * 100));
        }
    }
})();
